pub struct WhoisColorProtocol;Expand description
WHOIS-COLOR Protocol v1.1 A backward-compatible extension protocol for server-side colorization, Markdown rendering, and image display support
Implementations
Sourceimpl WhoisColorProtocol
impl WhoisColorProtocol
Sourcepub fn probe_capabilities(
&self,
server_address: &str,
verbose: bool,
) -> Result<ServerCapabilities>
pub fn probe_capabilities( &self, server_address: &str, verbose: bool, ) -> Result<ServerCapabilities>
Probe server for color protocol support This method sends a capability probe and waits for a response If no response or timeout, assumes standard WHOIS server
Sourcepub fn query_with_enhanced_protocol(
&self,
server_address: &str,
query: &str,
capabilities: &ServerCapabilities,
preferred_scheme: Option<&str>,
enable_markdown: bool,
enable_images: bool,
verbose: bool,
) -> Result<String>
pub fn query_with_enhanced_protocol( &self, server_address: &str, query: &str, capabilities: &ServerCapabilities, preferred_scheme: Option<&str>, enable_markdown: bool, enable_images: bool, verbose: bool, ) -> Result<String>
Perform query with enhanced protocol support (color, markdown, images) Falls back gracefully for older servers
Sourcepub fn is_server_colored(&self, response: &str) -> bool
pub fn is_server_colored(&self, response: &str) -> bool
Check if response contains server-generated colors Server-colored responses should contain color control sequences